@@ -14,13 +14,14 @@ log = logging.getLogger(__name__)
 class Logcat(AndroidExtraction):
     """This module extracts details on installed packages."""
 
-    def __init__(self, file_path=None, base_folder=None, output_folder=None,
-                 serial=None, fast_mode=False, log=None, results=[]):
-        super().__init__(file_path=file_path, base_folder=base_folder,
-                         output_folder=output_folder, fast_mode=fast_mode,
+    def __init__(self, file_path: str = None, target_path: str = None,
+                 results_path: str = None, fast_mode: bool = False,
+                 log: logging.Logger = None, results: list = []) -> None:
+        super().__init__(file_path=file_path, target_path=target_path,
+                         results_path=results_path, fast_mode=fast_mode,
                          log=log, results=results)
 
-    def run(self):
+    def run(self) -> None:
         self._adb_connect()
 
         # Get the current logcat.
@@ -28,8 +29,8 @@ class Logcat(AndroidExtraction):
         # Get the locat prior to last reboot.
         last_output = self._adb_command("logcat -L")
 
-        if self.output_folder:
-            logcat_path = os.path.join(self.output_folder,
+        if self.results_path:
+            logcat_path = os.path.join(self.results_path,
                                        "logcat.txt")
             with open(logcat_path, "w", encoding="utf-8") as handle:
                 handle.write(output)
@@ -37,7 +38,7 @@ class Logcat(AndroidExtraction):
             log.info("Current logcat logs stored at %s",
                      logcat_path)
 
-            logcat_last_path = os.path.join(self.output_folder,
+            logcat_last_path = os.path.join(self.results_path,
                                             "logcat_last.txt")
             with open(logcat_last_path, "w", encoding="utf-8") as handle:
                 handle.write(last_output)
