@@ -4,9 +4,6 @@
 #   https://license.mvt.re/1.1/
 
 import logging
-import os
-
-import pkg_resources
 
 from .base import AndroidExtraction
 
@@ -18,15 +15,16 @@ class SELinuxStatus(AndroidExtraction):
 
     slug = "selinux_status"
 
-    def __init__(self, file_path=None, base_folder=None, output_folder=None,
-                 serial=None, fast_mode=False, log=None, results=[]):
-        super().__init__(file_path=file_path, base_folder=base_folder,
-                         output_folder=output_folder, fast_mode=fast_mode,
+    def __init__(self, file_path: str = None, target_path: str = None,
+                 results_path: str = None, fast_mode: bool = False,
+                 log: logging.Logger = None, results: list = []) -> None:
+        super().__init__(file_path=file_path, target_path=target_path,
+                         results_path=results_path, fast_mode=fast_mode,
                          log=log, results=results)
 
         self.results = {} if not results else results
 
-    def run(self):
+    def run(self) -> None:
         self._adb_connect()
         output = self._adb_command("getenforce")
         self._adb_disconnect()
