@@ -5,6 +5,7 @@
 
 import fnmatch
 import os
+from tarfile import TarFile
 
 from mvt.common.module import MVTModule
 
@@ -13,14 +14,14 @@ class BackupExtraction(MVTModule):
     """This class provides a base for all backup extractios modules"""
     ab = None
 
-    def from_folder(self, backup_path, files):
+    def from_folder(self, backup_path: str, files: list) -> None:
         """
         Get all the files and list them
         """
         self.backup_path = backup_path
         self.files = files
 
-    def from_ab(self, file_path, tar, files):
+    def from_ab(self, file_path: str, tar: TarFile, files: list) -> None:
         """
         Extract the files
         """
@@ -28,10 +29,10 @@ class BackupExtraction(MVTModule):
         self.tar = tar
         self.files = files
 
-    def _get_files_by_pattern(self, pattern):
+    def _get_files_by_pattern(self, pattern: str) -> list:
         return fnmatch.filter(self.files, pattern)
 
-    def _get_file_content(self, file_path):
+    def _get_file_content(self, file_path: str) -> bytes:
         if self.ab:
             try:
                 member = self.tar.getmember(file_path)
@@ -43,4 +44,5 @@ class BackupExtraction(MVTModule):
 
         data = handle.read()
         handle.close()
+
         return data
