@@ -15,13 +15,14 @@ log = logging.getLogger(__name__)
 class Appops(BugReportModule):
     """This module extracts information on package from App-Ops Manager."""
 
-    def __init__(self, file_path=None, base_folder=None, output_folder=None,
-                 serial=None, fast_mode=False, log=None, results=[]):
-        super().__init__(file_path=file_path, base_folder=base_folder,
-                         output_folder=output_folder, fast_mode=fast_mode,
+    def __init__(self, file_path: str = None, target_path: str = None,
+                 results_path: str = None, fast_mode: bool = False,
+                 log: logging.Logger = None, results: list = []) -> None:
+        super().__init__(file_path=file_path, target_path=target_path,
+                         results_path=results_path, fast_mode=fast_mode,
                          log=log, results=results)
 
-    def serialize(self, record):
+    def serialize(self, record: dict) -> None:
         records = []
         for perm in record["permissions"]:
             if "entries" not in perm:
@@ -33,12 +34,12 @@ class Appops(BugReportModule):
                         "timestamp": entry["timestamp"],
                         "module": self.__class__.__name__,
                         "event": entry["access"],
-                        "data": f"{record['package_name']} access to {perm['name']} : {entry['access']}",
+                        "data": f"{record['package_name']} access to {perm['name']}: {entry['access']}",
                     })
 
         return records
 
-    def check_indicators(self):
+    def check_indicators(self) -> None:
         for result in self.results:
             if self.indicators:
                 ioc = self.indicators.check_app_id(result.get("package_name"))
@@ -51,7 +52,7 @@ class Appops(BugReportModule):
                 if perm["name"] == "REQUEST_INSTALL_PACKAGES" and perm["access"] == "allow":
                     self.log.info("Package %s with REQUEST_INSTALL_PACKAGES permission", result["package_name"])
 
-    def run(self):
+    def run(self) -> None:
         content = self._get_dumpstate_file()
         if not content:
             self.log.error("Unable to find dumpstate file. Did you provide a valid bug report archive?")
