@@ -6,6 +6,7 @@
 import fnmatch
 import logging
 import os
+from zipfile import ZipFile
 
 from mvt.common.module import MVTModule
 
@@ -17,15 +18,15 @@ class BugReportModule(MVTModule):
 
     zip_archive = None
 
-    def from_folder(self, extract_path, extract_files):
+    def from_folder(self, extract_path: str, extract_files: str) -> None:
         self.extract_path = extract_path
         self.extract_files = extract_files
 
-    def from_zip(self, zip_archive, zip_files):
+    def from_zip(self, zip_archive: ZipFile, zip_files: list) -> None:
         self.zip_archive = zip_archive
         self.zip_files = zip_files
 
-    def _get_files_by_pattern(self, pattern):
+    def _get_files_by_pattern(self, pattern: str) -> list:
         file_names = []
         if self.zip_archive:
             for zip_file in self.zip_files:
@@ -35,13 +36,13 @@ class BugReportModule(MVTModule):
 
         return fnmatch.filter(file_names, pattern)
 
-    def _get_files_by_patterns(self, patterns):
+    def _get_files_by_patterns(self, patterns: list) -> list:
         for pattern in patterns:
             matches = self._get_files_by_pattern(pattern)
             if matches:
                 return matches
 
-    def _get_file_content(self, file_path):
+    def _get_file_content(self, file_path: str) -> bytes:
         if self.zip_archive:
             handle = self.zip_archive.open(file_path)
         else:
@@ -52,7 +53,7 @@ class BugReportModule(MVTModule):
 
         return data
 
-    def _get_dumpstate_file(self):
+    def _get_dumpstate_file(self) -> bytes:
         main = self._get_files_by_pattern("main_entry.txt")
         if main:
             main_content = self._get_file_content(main[0])
