@@ -15,13 +15,14 @@ log = logging.getLogger(__name__)
 class BatteryDaily(BugReportModule):
     """This module extracts records from battery daily updates."""
 
-    def __init__(self, file_path=None, base_folder=None, output_folder=None,
-                 serial=None, fast_mode=False, log=None, results=[]):
-        super().__init__(file_path=file_path, base_folder=base_folder,
-                         output_folder=output_folder, fast_mode=fast_mode,
+    def __init__(self, file_path: str = None, target_path: str = None,
+                 results_path: str = None, fast_mode: bool = False,
+                 log: logging.Logger = None, results: list = []) -> None:
+        super().__init__(file_path=file_path, target_path=target_path,
+                         results_path=results_path, fast_mode=fast_mode,
                          log=log, results=results)
 
-    def serialize(self, record):
+    def serialize(self, record: dict) -> None:
         return {
             "timestamp": record["from"],
             "module": self.__class__.__name__,
@@ -29,7 +30,7 @@ class BatteryDaily(BugReportModule):
             "data": f"Recorded update of package {record['package_name']} with vers {record['vers']}"
         }
 
-    def check_indicators(self):
+    def check_indicators(self) -> None:
         if not self.indicators:
             return
 
@@ -40,7 +41,7 @@ class BatteryDaily(BugReportModule):
                 self.detected.append(result)
                 continue
 
-    def run(self):
+    def run(self) -> None:
         content = self._get_dumpstate_file()
         if not content:
             self.log.error("Unable to find dumpstate file. Did you provide a valid bug report archive?")
