@@ -4,8 +4,10 @@
 #   https://license.mvt.re/1.1/
 
 import csv
+import logging
 import os
 import re
+from typing import Callable
 
 import simplejson as json
 
@@ -28,16 +30,17 @@ class MVTModule(object):
     enabled = True
     slug = None
 
-    def __init__(self, file_path=None, base_folder=None, output_folder=None,
-                 fast_mode=False, log=None, results=None):
+    def __init__(self, file_path: str = None, target_path: str = None,
+                 results_path: str = None, fast_mode: bool = False,
+                 log: logging.Logger = None, results: list = None):
         """Initialize module.
 
         :param file_path: Path to the module's database file, if there is any
         :type file_path: str
-        :param base_folder: Path to the base folder (backup or filesystem dump)
+        :param target_path: Path to the target folder (backup or filesystem dump)
         :type file_path: str
-        :param output_folder: Folder where results will be stored
-        :type output_folder: str
+        :param results_path: Folder where results will be stored
+        :type results_path: str
         :param fast_mode: Flag to enable or disable slow modules
         :type fast_mode: bool
         :param log: Handle to logger
@@ -45,8 +48,8 @@ class MVTModule(object):
         :type results: list
         """
         self.file_path = file_path
-        self.base_folder = base_folder
-        self.output_folder = output_folder
+        self.target_path = target_path
+        self.results_path = results_path
         self.fast_mode = fast_mode
         self.log = log
         self.indicators = None
@@ -56,7 +59,7 @@ class MVTModule(object):
         self.timeline_detected = []
 
     @classmethod
-    def from_json(cls, json_path, log=None):
+    def from_json(cls, json_path: str, log: logging.Logger = None):
         with open(json_path, "r", encoding="utf-8") as handle:
             results = json.load(handle)
             if log:
@@ -64,7 +67,7 @@ class MVTModule(object):
                          len(results), json_path)
             return cls(results=results, log=log)
 
-    def get_slug(self):
+    def get_slug(self) -> str:
         """Use the module's class name to retrieve a slug"""
         if self.slug:
             return self.slug
@@ -72,7 +75,7 @@ class MVTModule(object):
         sub = re.sub("(.)([A-Z][a-z]+)", r"\1_\2", self.__class__.__name__)
         return re.sub("([a-z0-9])([A-Z])", r"\1_\2", sub).lower()
 
-    def check_indicators(self):
+    def check_indicators(self) -> None:
         """Check the results of this module against a provided list of
         indicators.
 
@@ -80,16 +83,16 @@ class MVTModule(object):
         """
         raise NotImplementedError
 
-    def save_to_json(self):
+    def save_to_json(self) -> None:
         """Save the collected results to a json file."""
-        if not self.output_folder:
+        if not self.results_path:
             return
 
         name = self.get_slug()
 
         if self.results:
             results_file_name = f"{name}.json"
-            results_json_path = os.path.join(self.output_folder, results_file_name)
+            results_json_path = os.path.join(self.results_path, results_file_name)
             with open(results_json_path, "w", encoding="utf-8") as handle:
                 try:
                     json.dump(self.results, handle, indent=4, default=str)
@@ -99,15 +102,15 @@ class MVTModule(object):
 
         if self.detected:
             detected_file_name = f"{name}_detected.json"
-            detected_json_path = os.path.join(self.output_folder, detected_file_name)
+            detected_json_path = os.path.join(self.results_path, detected_file_name)
             with open(detected_json_path, "w", encoding="utf-8") as handle:
                 json.dump(self.detected, handle, indent=4, default=str)
 
-    def serialize(self, record):
+    def serialize(self, record: dict) -> None:
         raise NotImplementedError
 
     @staticmethod
-    def _deduplicate_timeline(timeline):
+    def _deduplicate_timeline(timeline: list) -> list:
         """Serialize entry as JSON to deduplicate repeated entries
 
         :param timeline: List of entries from timeline to deduplicate
@@ -118,7 +121,7 @@ class MVTModule(object):
             timeline_set.add(json.dumps(record, sort_keys=True))
         return [json.loads(record) for record in timeline_set]
 
-    def to_timeline(self):
+    def to_timeline(self) -> None:
         """Convert results into a timeline."""
         for result in self.results:
             record = self.serialize(result)
@@ -140,12 +143,12 @@ class MVTModule(object):
         self.timeline = self._deduplicate_timeline(self.timeline)
         self.timeline_detected = self._deduplicate_timeline(self.timeline_detected)
 
-    def run(self):
+    def run(self) -> None:
         """Run the main module procedure."""
         raise NotImplementedError
 
 
-def run_module(module):
+def run_module(module: Callable) -> None:
     module.log.info("Running module %s...", module.__class__.__name__)
 
     try:
@@ -184,7 +187,7 @@ def run_module(module):
         module.save_to_json()
 
 
-def save_timeline(timeline, timeline_path):
+def save_timeline(timeline: list, timeline_path: str) -> None:
     """Save the timeline in a csv file.
 
     :param timeline: List of records to order and store
@@ -192,7 +195,8 @@ def save_timeline(timeline, timeline_path):
 
     """
     with open(timeline_path, "a+", encoding="utf-8") as handle:
-        csvoutput = csv.writer(handle, delimiter=",", quotechar="\"")
+        csvoutput = csv.writer(handle, delimiter=",", quotechar="\"",
+                               quoting=csv.QUOTE_ALL)
         csvoutput.writerow(["UTC Timestamp", "Plugin", "Event", "Description"])
         for event in sorted(timeline, key=lambda x: x["timestamp"] if x["timestamp"] is not None else ""):
             csvoutput.writerow([
