@@ -10,14 +10,16 @@ import click
 from rich.logging import RichHandler
 from rich.prompt import Prompt
 
+from mvt.common.cmd_check_iocs import CmdCheckIOCS
 from mvt.common.help import (HELP_MSG_FAST, HELP_MSG_IOC,
                              HELP_MSG_LIST_MODULES, HELP_MSG_MODULE,
                              HELP_MSG_OUTPUT)
-from mvt.common.indicators import Indicators, download_indicators_files
 from mvt.common.logo import logo
-from mvt.common.module import run_module, save_timeline
 from mvt.common.options import MutuallyExclusiveOption
+from mvt.common.updates import IndicatorsUpdates
 
+from .cmd_check_backup import CmdIOSCheckBackup
+from .cmd_check_fs import CmdIOSCheckFS
 from .decrypt import DecryptBackup
 from .modules.backup import BACKUP_MODULES
 from .modules.fs import FS_MODULES
@@ -30,7 +32,7 @@ logging.basicConfig(level="INFO", format=LOG_FORMAT, handlers=[
 log = logging.getLogger(__name__)
 
 # Set this environment variable to a password if needed.
-PASSWD_ENV = "MVT_IOS_BACKUP_PASSWORD"
+MVT_IOS_BACKUP_PASSWORD = "MVT_IOS_BACKUP_PASSWORD"
 
 
 #==============================================================================
@@ -56,7 +58,7 @@ def version():
 @click.option("--destination", "-d", required=True,
               help="Path to the folder where to store the decrypted backup")
 @click.option("--password", "-p", cls=MutuallyExclusiveOption,
-              help=f"Password to use to decrypt the backup (or, set {PASSWD_ENV} environment variable)",
+              help=f"Password to use to decrypt the backup (or, set {MVT_IOS_BACKUP_PASSWORD} environment variable)",
               mutually_exclusive=["key_file"])
 @click.option("--key-file", "-k", cls=MutuallyExclusiveOption,
               type=click.Path(exists=True),
@@ -68,22 +70,22 @@ def decrypt_backup(ctx, destination, password, key_file, backup_path):
     backup = DecryptBackup(backup_path, destination)
 
     if key_file:
-        if PASSWD_ENV in os.environ:
+        if MVT_IOS_BACKUP_PASSWORD in os.environ:
             log.info("Ignoring environment variable, using --key-file '%s' instead",
-                     PASSWD_ENV, key_file)
+                     MVT_IOS_BACKUP_PASSWORD, key_file)
 
         backup.decrypt_with_key_file(key_file)
     elif password:
         log.info("Your password may be visible in the process table because it was supplied on the command line!")
 
-        if PASSWD_ENV in os.environ:
+        if MVT_IOS_BACKUP_PASSWORD in os.environ:
             log.info("Ignoring %s environment variable, using --password argument instead",
-                     PASSWD_ENV)
+                     MVT_IOS_BACKUP_PASSWORD)
 
         backup.decrypt_with_password(password)
-    elif PASSWD_ENV in os.environ:
-        log.info("Using password from %s environment variable", PASSWD_ENV)
-        backup.decrypt_with_password(os.environ[PASSWD_ENV])
+    elif MVT_IOS_BACKUP_PASSWORD in os.environ:
+        log.info("Using password from %s environment variable", MVT_IOS_BACKUP_PASSWORD)
+        backup.decrypt_with_password(os.environ[MVT_IOS_BACKUP_PASSWORD])
     else:
         sekrit = Prompt.ask("Enter backup password", password=True)
         backup.decrypt_with_password(sekrit)
@@ -99,24 +101,24 @@ def decrypt_backup(ctx, destination, password, key_file, backup_path):
 #==============================================================================
 @cli.command("extract-key", help="Extract decryption key from an iTunes backup")
 @click.option("--password", "-p",
-              help=f"Password to use to decrypt the backup (or, set {PASSWD_ENV} environment variable)")
+              help=f"Password to use to decrypt the backup (or, set {MVT_IOS_BACKUP_PASSWORD} environment variable)")
 @click.option("--key-file", "-k",
               help="Key file to be written (if unset, will print to STDOUT)",
               required=False,
               type=click.Path(exists=False, file_okay=True, dir_okay=False, writable=True))
 @click.argument("BACKUP_PATH", type=click.Path(exists=True))
-def extract_key(password, backup_path, key_file):
+def extract_key(password, key_file, backup_path):
     backup = DecryptBackup(backup_path)
 
     if password:
         log.info("Your password may be visible in the process table because it was supplied on the command line!")
 
-        if PASSWD_ENV in os.environ:
+        if MVT_IOS_BACKUP_PASSWORD in os.environ:
             log.info("Ignoring %s environment variable, using --password argument instead",
-                     PASSWD_ENV)
-    elif PASSWD_ENV in os.environ:
-        log.info("Using password from %s environment variable", PASSWD_ENV)
-        password = os.environ[PASSWD_ENV]
+                     MVT_IOS_BACKUP_PASSWORD)
+    elif MVT_IOS_BACKUP_PASSWORD in os.environ:
+        log.info("Using password from %s environment variable", MVT_IOS_BACKUP_PASSWORD)
+        password = os.environ[MVT_IOS_BACKUP_PASSWORD]
     else:
         password = Prompt.ask("Enter backup password", password=True)
 
@@ -139,52 +141,21 @@ def extract_key(password, backup_path, key_file):
 @click.option("--module", "-m", help=HELP_MSG_MODULE)
 @click.argument("BACKUP_PATH", type=click.Path(exists=True))
 @click.pass_context
-def check_backup(ctx, iocs, output, fast, backup_path, list_modules, module):
-    if list_modules:
-        log.info("Following is the list of available check-backup modules:")
-        for backup_module in BACKUP_MODULES + MIXED_MODULES:
-            log.info(" - %s", backup_module.__name__)
+def check_backup(ctx, iocs, output, fast, list_modules, module, backup_path):
+    cmd = CmdIOSCheckBackup(target_path=backup_path, results_path=output,
+                            ioc_files=iocs, module_name=module, fast_mode=fast)
 
+    if list_modules:
+        cmd.list_modules()
         return
 
     log.info("Checking iTunes backup located at: %s", backup_path)
 
-    if output and not os.path.exists(output):
-        try:
-            os.makedirs(output)
-        except Exception as e:
-            log.critical("Unable to create output folder %s: %s", output, e)
-            ctx.exit(1)
+    cmd.run()
 
-    indicators = Indicators(log=log)
-    indicators.load_indicators_files(iocs)
-
-    timeline = []
-    timeline_detected = []
-    for backup_module in BACKUP_MODULES + MIXED_MODULES:
-        if module and backup_module.__name__ != module:
-            continue
-
-        m = backup_module(base_folder=backup_path, output_folder=output, fast_mode=fast,
-                          log=logging.getLogger(backup_module.__module__))
-        m.is_backup = True
-        if indicators.total_ioc_count > 0:
-            m.indicators = indicators
-            m.indicators.log = m.log
-
-        run_module(m)
-        timeline.extend(m.timeline)
-        timeline_detected.extend(m.timeline_detected)
-
-    if output:
-        if len(timeline) > 0:
-            save_timeline(timeline, os.path.join(output, "timeline.csv"))
-        if len(timeline_detected) > 0:
-            save_timeline(timeline_detected, os.path.join(output, "timeline_detected.csv"))
-
-    if len(timeline_detected) > 0:
+    if len(cmd.timeline_detected) > 0:
         log.warning("The analysis of the backup produced %d detections!",
-                    len(timeline_detected))
+                    len(cmd.timeline_detected))
 
 
 #==============================================================================
@@ -199,53 +170,21 @@ def check_backup(ctx, iocs, output, fast, backup_path, list_modules, module):
 @click.option("--module", "-m", help=HELP_MSG_MODULE)
 @click.argument("DUMP_PATH", type=click.Path(exists=True))
 @click.pass_context
-def check_fs(ctx, iocs, output, fast, dump_path, list_modules, module):
-    if list_modules:
-        log.info("Following is the list of available check-fs modules:")
-        for fs_module in FS_MODULES + MIXED_MODULES:
-            log.info(" - %s", fs_module.__name__)
+def check_fs(ctx, iocs, output, fast, list_modules, module, dump_path):
+    cmd = CmdIOSCheckFS(target_path=dump_path, results_path=output,
+                        ioc_files=iocs, module_name=module, fast_mode=fast)
 
+    if list_modules:
+        cmd.list_modules()
         return
 
-    log.info("Checking filesystem dump located at: %s", dump_path)
+    log.info("Checking iOS filesystem located at: %s", dump_path)
 
-    if output and not os.path.exists(output):
-        try:
-            os.makedirs(output)
-        except Exception as e:
-            log.critical("Unable to create output folder %s: %s", output, e)
-            ctx.exit(1)
+    cmd.run()
 
-    indicators = Indicators(log=log)
-    indicators.load_indicators_files(iocs)
-
-    timeline = []
-    timeline_detected = []
-    for fs_module in FS_MODULES + MIXED_MODULES:
-        if module and fs_module.__name__ != module:
-            continue
-
-        m = fs_module(base_folder=dump_path, output_folder=output, fast_mode=fast,
-                      log=logging.getLogger(fs_module.__module__))
-
-        m.is_fs_dump = True
-        if indicators.total_ioc_count > 0:
-            m.indicators = indicators
-            m.indicators.log = m.log
-
-        run_module(m)
-        timeline.extend(m.timeline)
-        timeline_detected.extend(m.timeline_detected)
-
-    if output:
-        if len(timeline) > 0:
-            save_timeline(timeline, os.path.join(output, "timeline.csv"))
-        if len(timeline_detected) > 0:
-            save_timeline(timeline_detected, os.path.join(output, "timeline_detected.csv"))
-
-    if len(timeline_detected) > 0:
-        log.warning("The analysis of the filesystem produced %d detections!",
-                    len(timeline_detected))
+    if len(cmd.timeline_detected) > 0:
+        log.warning("The analysis of the iOS filesystem produced %d detections!",
+                    len(cmd.timeline_detected))
 
 
 #==============================================================================
@@ -259,54 +198,14 @@ def check_fs(ctx, iocs, output, fast, dump_path, list_modules, module):
 @click.argument("FOLDER", type=click.Path(exists=True))
 @click.pass_context
 def check_iocs(ctx, iocs, list_modules, module, folder):
-    all_modules = []
-    for entry in BACKUP_MODULES + FS_MODULES + MIXED_MODULES:
-        if entry not in all_modules:
-            all_modules.append(entry)
+    cmd = CmdCheckIOCS(target_path=folder, ioc_files=iocs, module_name=module)
+    cmd.modules = BACKUP_MODULES + FS_MODULES + MIXED_MODULES
 
     if list_modules:
-        log.info("Following is the list of available check-iocs modules:")
-        for iocs_module in all_modules:
-            log.info(" - %s", iocs_module.__name__)
-
+        cmd.list_modules()
         return
 
-    log.info("Checking stored results against provided indicators...")
-
-    indicators = Indicators(log=log)
-    indicators.load_indicators_files(iocs)
-
-    total_detections = 0
-    for file_name in os.listdir(folder):
-        name_only, ext = os.path.splitext(file_name)
-        file_path = os.path.join(folder, file_name)
-
-        for iocs_module in all_modules:
-            if module and iocs_module.__name__ != module:
-                continue
-
-            if iocs_module().get_slug() != name_only:
-                continue
-
-            log.info("Loading results from \"%s\" with module %s", file_name,
-                     iocs_module.__name__)
-
-            m = iocs_module.from_json(file_path,
-                                      log=logging.getLogger(iocs_module.__module__))
-            if indicators.total_ioc_count > 0:
-                m.indicators = indicators
-                m.indicators.log = m.log
-
-            try:
-                m.check_indicators()
-            except NotImplementedError:
-                continue
-            else:
-                total_detections += len(m.detected)
-
-    if total_detections > 0:
-        log.warning("The check of the results produced %d detections!",
-                    total_detections)
+    cmd.run()
 
 
 #==============================================================================
@@ -314,4 +213,5 @@ def check_iocs(ctx, iocs, list_modules, module, folder):
 #==============================================================================
 @cli.command("download-iocs", help="Download public STIX2 indicators")
 def download_iocs():
-    download_indicators_files(log)
+    ioc_updates = IndicatorsUpdates()
+    ioc_updates.update()
