@@ -3,6 +3,7 @@
 # Use of this software is governed by the MVT License 1.1 that can be found at
 #   https://license.mvt.re/1.1/
 
+import logging
 import os
 import sqlite3
 
@@ -11,13 +12,14 @@ from ..base import IOSExtraction
 
 class CacheFiles(IOSExtraction):
 
-    def __init__(self, file_path=None, base_folder=None, output_folder=None,
-                 fast_mode=False, log=None, results=[]):
-        super().__init__(file_path=file_path, base_folder=base_folder,
-                         output_folder=output_folder, fast_mode=fast_mode,
+    def __init__(self, file_path: str = None, target_path: str = None,
+                 results_path: str = None, fast_mode: bool = False,
+                 log: logging.Logger = None, results: list = []) -> None:
+        super().__init__(file_path=file_path, target_path=target_path,
+                         results_path=results_path, fast_mode=fast_mode,
                          log=log, results=results)
 
-    def serialize(self, record):
+    def serialize(self, record: dict) -> None:
         records = []
         for item in self.results[record]:
             records.append({
@@ -29,7 +31,7 @@ class CacheFiles(IOSExtraction):
 
         return records
 
-    def check_indicators(self):
+    def check_indicators(self) -> None:
         if not self.indicators:
             return
 
@@ -55,7 +57,7 @@ class CacheFiles(IOSExtraction):
         except sqlite3.OperationalError:
             return
 
-        key_name = os.path.relpath(file_path, self.base_folder)
+        key_name = os.path.relpath(file_path, self.target_path)
         if key_name not in self.results:
             self.results[key_name] = []
 
@@ -69,9 +71,9 @@ class CacheFiles(IOSExtraction):
                 "isodate": row[5],
             })
 
-    def run(self):
+    def run(self) -> None:
         self.results = {}
-        for root, dirs, files in os.walk(self.base_folder):
+        for root, dirs, files in os.walk(self.target_path):
             for file_name in files:
                 if file_name != "Cache.db":
                     continue
