@@ -4,6 +4,7 @@
 #   https://license.mvt.re/1.1/
 
 import datetime
+import logging
 import os
 
 from mvt.common.utils import convert_timestamp_to_iso
@@ -18,13 +19,14 @@ class Filesystem(IOSExtraction):
 
     """
 
-    def __init__(self, file_path=None, base_folder=None, output_folder=None,
-                 fast_mode=False, log=None, results=[]):
-        super().__init__(file_path=file_path, base_folder=base_folder,
-                         output_folder=output_folder, fast_mode=fast_mode,
+    def __init__(self, file_path: str = None, target_path: str = None,
+                 results_path: str = None, fast_mode: bool = False,
+                 log: logging.Logger = None, results: list = []) -> None:
+        super().__init__(file_path=file_path, target_path=target_path,
+                         results_path=results_path, fast_mode=fast_mode,
                          log=log, results=results)
 
-    def serialize(self, record):
+    def serialize(self, record: dict) -> None:
         return {
             "timestamp": record["modified"],
             "module": self.__class__.__name__,
@@ -32,7 +34,7 @@ class Filesystem(IOSExtraction):
             "data": record["path"],
         }
 
-    def check_indicators(self):
+    def check_indicators(self) -> None:
         if not self.indicators:
             return
 
@@ -57,13 +59,13 @@ class Filesystem(IOSExtraction):
                     result["matched_indicator"] = ioc
                     self.detected.append(result)
 
-    def run(self):
-        for root, dirs, files in os.walk(self.base_folder):
+    def run(self) -> None:
+        for root, dirs, files in os.walk(self.target_path):
             for dir_name in dirs:
                 try:
                     dir_path = os.path.join(root, dir_name)
                     result = {
-                        "path": os.path.relpath(dir_path, self.base_folder),
+                        "path": os.path.relpath(dir_path, self.target_path),
                         "modified": convert_timestamp_to_iso(datetime.datetime.utcfromtimestamp(os.stat(dir_path).st_mtime)),
                     }
                 except Exception:
@@ -75,7 +77,7 @@ class Filesystem(IOSExtraction):
                 try:
                     file_path = os.path.join(root, file_name)
                     result = {
-                        "path": os.path.relpath(file_path, self.base_folder),
+                        "path": os.path.relpath(file_path, self.target_path),
                         "modified": convert_timestamp_to_iso(datetime.datetime.utcfromtimestamp(os.stat(file_path).st_mtime)),
                     }
                 except Exception:
