@@ -3,6 +3,7 @@
 # Use of this software is governed by the MVT License 1.1 that can be found at
 #   https://license.mvt.re/1.1/
 
+import logging
 import os
 import sqlite3
 
@@ -25,13 +26,14 @@ class SafariHistory(IOSExtraction):
 
     """
 
-    def __init__(self, file_path=None, base_folder=None, output_folder=None,
-                 fast_mode=False, log=None, results=[]):
-        super().__init__(file_path=file_path, base_folder=base_folder,
-                         output_folder=output_folder, fast_mode=fast_mode,
+    def __init__(self, file_path: str = None, target_path: str = None,
+                 results_path: str = None, fast_mode: bool = False,
+                 log: logging.Logger = None, results: list = []) -> None:
+        super().__init__(file_path=file_path, target_path=target_path,
+                         results_path=results_path, fast_mode=fast_mode,
                          log=log, results=results)
 
-    def serialize(self, record):
+    def serialize(self, record: dict) -> None:
         return {
             "timestamp": record["isodate"],
             "module": self.__class__.__name__,
@@ -73,7 +75,7 @@ class SafariHistory(IOSExtraction):
                 if elapsed_time.seconds == 0:
                     self.log.warning("Redirect took less than a second! (%d milliseconds)", elapsed_ms)
 
-    def check_indicators(self):
+    def check_indicators(self) -> None:
         self._find_injections()
 
         if not self.indicators:
@@ -111,13 +113,13 @@ class SafariHistory(IOSExtraction):
                 "isodate": convert_timestamp_to_iso(convert_mactime_to_unix(row[3])),
                 "redirect_source": row[4],
                 "redirect_destination": row[5],
-                "safari_history_db": os.path.relpath(history_path, self.base_folder),
+                "safari_history_db": os.path.relpath(history_path, self.target_path),
             })
 
         cur.close()
         conn.close()
 
-    def run(self):
+    def run(self) -> None:
         if self.is_backup:
             for history_file in self._get_backup_files_from_manifest(relative_path=SAFARI_HISTORY_BACKUP_RELPATH):
                 history_path = self._get_backup_file_from_id(history_file["file_id"])
