@@ -3,6 +3,7 @@
 # Use of this software is governed by the MVT License 1.1 that can be found at
 #   https://license.mvt.re/1.1/
 
+import logging
 import os
 import plistlib
 
@@ -29,10 +30,11 @@ class WebkitSessionResourceLog(IOSExtraction):
 
     """
 
-    def __init__(self, file_path=None, base_folder=None, output_folder=None,
-                 fast_mode=False, log=None, results=[]):
-        super().__init__(file_path=file_path, base_folder=base_folder,
-                         output_folder=output_folder, fast_mode=fast_mode,
+    def __init__(self, file_path: str = None, target_path: str = None,
+                 results_path: str = None, fast_mode: bool = False,
+                 log: logging.Logger = None, results: list = []) -> None:
+        super().__init__(file_path=file_path, target_path=target_path,
+                         results_path=results_path, fast_mode=fast_mode,
                          log=log, results=results)
 
         self.results = {} if not results else results
@@ -51,7 +53,7 @@ class WebkitSessionResourceLog(IOSExtraction):
 
         return domains
 
-    def check_indicators(self):
+    def check_indicators(self) -> None:
         if not self.indicators:
             return
 
@@ -117,7 +119,7 @@ class WebkitSessionResourceLog(IOSExtraction):
 
         return items
 
-    def run(self):
+    def run(self) -> None:
         if self.is_backup:
             for log_file in self._get_backup_files_from_manifest(relative_path=WEBKIT_SESSION_RESOURCE_LOG_BACKUP_RELPATH):
                 log_path = self._get_backup_file_from_id(log_file["file_id"])
@@ -128,7 +130,7 @@ class WebkitSessionResourceLog(IOSExtraction):
         elif self.is_fs_dump:
             for log_path in self._get_fs_files_from_patterns(WEBKIT_SESSION_RESOURCE_LOG_ROOT_PATHS):
                 self.log.info("Found Safari browsing session resource log at path: %s", log_path)
-                key = os.path.relpath(log_path, self.base_folder)
+                key = os.path.relpath(log_path, self.target_path)
                 self.results[key] = self._extract_browsing_stats(log_path)
 
         self.log.info("Extracted records from %d Safari browsing session resource logs",
