@@ -3,6 +3,7 @@
 # Use of this software is governed by the MVT License 1.1 that can be found at
 #   https://license.mvt.re/1.1/
 
+import logging
 import operator
 import sqlite3
 from pathlib import Path
@@ -15,10 +16,11 @@ from .base import IOSExtraction
 class NetBase(IOSExtraction):
     """This class provides a base for DataUsage and NetUsage extraction modules."""
 
-    def __init__(self, file_path=None, base_folder=None, output_folder=None,
-                 fast_mode=False, log=None, results=[]):
-        super().__init__(file_path=file_path, base_folder=base_folder,
-                         output_folder=output_folder, fast_mode=fast_mode,
+    def __init__(self, file_path: str = None, target_path: str = None,
+                 results_path: str = None, fast_mode: bool = False,
+                 log: logging.Logger = None, results: list = []) -> None:
+        super().__init__(file_path=file_path, target_path=target_path,
+                         results_path=results_path, fast_mode=fast_mode,
                          log=log, results=results)
 
     def _extract_net_data(self):
@@ -78,7 +80,7 @@ class NetBase(IOSExtraction):
 
         self.log.info("Extracted information on %d processes", len(self.results))
 
-    def serialize(self, record):
+    def serialize(self, record: dict) -> None:
         record_data = f"{record['proc_name']} (Bundle ID: {record['bundle_id']}, ID: {record['proc_id']})"
         record_data_usage = record_data + f" WIFI IN: {record['wifi_in']}, WIFI OUT: {record['wifi_out']} - "  \
             f"WWAN IN: {record['wwan_in']}, WWAN OUT: {record['wwan_out']}"
@@ -124,7 +126,7 @@ class NetBase(IOSExtraction):
         self.log.info("Extended search for suspicious processes ...")
 
         files = []
-        for posix_path in Path(self.base_folder).rglob("*"):
+        for posix_path in Path(self.target_path).rglob("*"):
             try:
                 if not posix_path.is_file():
                     continue
@@ -148,13 +150,13 @@ class NetBase(IOSExtraction):
                 else:
                     msg = f"Could not find the binary associated with the process with name {proc['proc_name']}"
                     if (proc["proc_name"] is None):
-                        msg = f"Found process entry with empty 'proc_name' : {proc['live_proc_id']} at {proc['live_isodate']}"
+                        msg = f"Found process entry with empty 'proc_name': {proc['live_proc_id']} at {proc['live_isodate']}"
                     elif len(proc["proc_name"]) == 16:
                         msg = msg + " (However, the process name might have been truncated in the database)"
 
                     self.log.warning(msg)
             if not proc["live_proc_id"]:
-                self.log.info(f"Found process entry in ZPROCESS but not in ZLIVEUSAGE : {proc['proc_name']} at {proc['live_isodate']}")
+                self.log.info(f"Found process entry in ZPROCESS but not in ZLIVEUSAGE: {proc['proc_name']} at {proc['live_isodate']}")
 
     def check_manipulated(self):
         """Check for missing or manipulate DB entries"""
@@ -214,7 +216,7 @@ class NetBase(IOSExtraction):
 
         self.results = sorted(self.results, key=operator.itemgetter("first_isodate"))
 
-    def check_indicators(self):
+    def check_indicators(self) -> None:
         # Check for manipulated process records.
         # TODO: Catching KeyError for live_isodate for retro-compatibility.
         #       This is not very good.
